% Author: Veronika Svozilova
% Institution: The University Hospital Brno
% Personal e-mail adress: fauxpas.gkj@gmail.com

% function 'bounding_of_gait_cycles' serves to determine the borders of thegait
% cycles for both lower limbs
function [fs_right_b, fs_right_e, fs_left_b, fs_left_e] = bounding_of_gait_cycles(Events)

% the input structure 'Events.mat' must contain seven time-marks for the left and the right gait cycle (or five time-marks for the left and the right gait cycle separately) and four fields to
% precise determination of the gait cycles
len_of_structure = length(Events);
num_of_fields = length(fieldnames(Events)); 

if len_of_structure >= 7 && num_of_fields >= 4;
    
   % the structure 'Events.mat' is stored in the auxiliary variable 'pom_event' which is preferable to the further work
   pom_event = cell(len_of_structure,num_of_fields);

    for k = 1:len_of_structure;
                
        pom_event{k, 1} = Events(1,k).label;
        pom_event{k, 2} = Events(1,k).context;
        pom_event{k, 3} = Events(1,k).time;
        pom_event{k, 4} = Events(1,k).frame;
          
    end

   % marking the beginning and the end of the gait cycles from the input structure
   % 'Events.mat'
   b = Events(1).label;   
   e = Events(7).label;
   
   % if the input data from the gait laboratory are acquired accurately,
   % first and seventh time-mark should be 'Foot Strike' and the gait
   % cycle of the right AND the left lower limb can be bounded
   % simulthaneously
   log_value = strcmp(b,e);
   
    if log_value == 1; 
    
       foot_strike = find(strcmp([pom_event(:,1)],'Foot Strike'));
       right = find(strcmp([pom_event(:,2)],'Right'));
       left = find(strcmp([pom_event(:,2)],'Left'));

       foot_strike_right = intersect(foot_strike,right);
       foot_strike_left = intersect(foot_strike,left);

       fs_right_b = pom_event{foot_strike_right(1), 4};
       fs_right_e = pom_event{foot_strike_right(2), 4};

       fs_left_b = pom_event{foot_strike_left(1), 4};
       fs_left_e = pom_event{foot_strike_left(2), 4};
       
    else
        
    fs_right_b = 0;
    fs_right_e = 0;
    
    fs_left_b = 0;
    fs_left_e = 0;
    
    end
    
elseif len_of_structure == 5 || len_of_structure == 6 && num_of_fields >= 4; 
    
    % the structure 'Events.mat' is stored in the auxiliary variable 'pom_event' which is preferable to the further work
    pom_event = cell(len_of_structure,num_of_fields);

     for k = 1:len_of_structure;
                
         pom_event{k, 1} = Events(1,k).label;
         pom_event{k, 2} = Events(1,k).context;
         pom_event{k, 3} = Events(1,k).time;
         pom_event{k, 4} = Events(1,k).frame;
          
     end
    
    % marking the beginning and the end of the gait cycle from the input structure
    % 'Events.mat'
    b = Events(1).label;   
    e = Events(5).label;
    
    % if the input data from the gait laboratory are acquired accurately,
    % first and fifth time-mark should be 'Foot Strike' and the gait
    % cycle of the right OR the left lower limb can be bounded
    log_value = strcmp(b,e);
    
     if log_value == 1 
    
        foot_strike = find(strcmp([pom_event(:,1)],'Foot Strike'));
        right = find(strcmp([pom_event(:,2)],'Right'));
        left = find(strcmp([pom_event(:,2)],'Left'));

        foot_strike_right = intersect(foot_strike,right);
        foot_strike_left = intersect(foot_strike,left);
        
        % if the structure 'Events.mat' contains only the right gait cycle
        if length(foot_strike_right) == 2 && length(foot_strike_left) == 1
           
           fs_right_b = pom_event{foot_strike_right(1), 4};
           fs_right_e = pom_event{foot_strike_right(2), 4};

           fs_left_b = 0;
           fs_left_e = 0;
       
        % if the structure 'Events.mat' contains only the left gait cycle
        elseif length(foot_strike_right) == 1 && length(foot_strike_left) == 2
           
           fs_left_b = pom_event{foot_strike_left(1), 4};
           fs_left_e = pom_event{foot_strike_left(2), 4};
       
           fs_right_b = 0;
           fs_right_e = 0;
       
        else
           
           fs_right_b = 0;
           fs_right_e = 0;  
           fs_left_b = 0;
           fs_left_e = 0;
       
        end

     else 
       
        fs_right_b = 0;
        fs_right_e = 0;  
        fs_left_b = 0;
        fs_left_e = 0;

     end
    
else
    
    fs_right_b = 0;
    fs_right_e = 0;
    
    fs_left_b = 0;
    fs_left_e = 0;
    
end


end