% Author: Veronika Svozilova
% Institution: The University Hospital Brno
% Personal e-mail adress: fauxpas.gkj@gmail.com

% function 'selection_of_gait_cycles_variables_left_limb' serves to select
% the variables describing the gait cycle in the three planes (the frontal, the sagittal,
% the transversal) for the left lower limb
function [left_data_xyz, left_variables_xyz, left_data_double, dif_b_left, dif_e_left] = selection_of_gait_cycles_variables_left_limb(Markers,fs_left_b, fs_left_e)

% define the length of the normalised gait cycle and the auxiliary variable 'pom_l'
% to which the variables of the structure 'Markers.mat' will be stored
length_of_normalised_gait_cycle = 101;
pom_l = zeros(1,length(Markers.Labels));

% define and find the location of the variables describing the gait cycles in the input structure 'Markers.mat', the location of these
% variables are stored into the variable 'pom_l'
LFEO = find(strcmp([Markers.Labels],'LFEO'));
pom_l(LFEO) = 1;
LFEA = find(strcmp([Markers.Labels],'LFEA'));
pom_l(LFEA) = 1;
LFEL = find(strcmp([Markers.Labels],'LFEL'));
pom_l(LFEL) = 1;
LFEP = find(strcmp([Markers.Labels],'LFEP'));
pom_l(LFEP) = 1;
LFOO = find(strcmp([Markers.Labels],'LFOO'));
pom_l(LFOO) = 1;
LFOA = find(strcmp([Markers.Labels],'LFOA'));
pom_l(LFOA) = 1;
LFOL = find(strcmp([Markers.Labels],'LFOL'));
pom_l(LFOL) = 1;
LFOP = find(strcmp([Markers.Labels],'LFOP'));
pom_l(LFOP) = 1;
LTIO = find(strcmp([Markers.Labels],'LTIO'));
pom_l(LTIO) = 1;
LTIA = find(strcmp([Markers.Labels],'LTIA'));
pom_l(LTIA) = 1;
LTIL = find(strcmp([Markers.Labels],'LTIL'));
pom_l(LTIL) = 1;
LTIP = find(strcmp([Markers.Labels],'LTIP'));
pom_l(LTIP) = 1;
LTOO = find(strcmp([Markers.Labels],'LTOO'));
pom_l(LTOO) = 1;
LTOA = find(strcmp([Markers.Labels],'LTOA'));
pom_l(LTOA) = 1;
LTOL = find(strcmp([Markers.Labels],'LTOL'));
pom_l(LTOL) = 1;
LTOP = find(strcmp([Markers.Labels],'LTOP'));
pom_l(LTOP) = 1;
PELO = find(strcmp([Markers.Labels],'PELO'));
pom_l(PELO) = 1;
PELA = find(strcmp([Markers.Labels],'PELA'));
pom_l(PELA) = 1;
PELL = find(strcmp([Markers.Labels],'PELL'));
pom_l(PELL) = 1;
PELP = find(strcmp([Markers.Labels],'PELP'));
pom_l(PELP) = 1;
LASI = find(strcmp([Markers.Labels],'LASI'));
pom_l(LASI) = 1;
LPSI = find(strcmp([Markers.Labels],'LPSI'));
pom_l(LPSI) = 1;
LTHI = find(strcmp([Markers.Labels],'LTHI'));
pom_l(LTHI) = 1;
LKNE = find(strcmp([Markers.Labels],'LKNE'));
pom_l(LKNE) = 1;
LTIB = find(strcmp([Markers.Labels],'LTIB'));
pom_l(LTIB) = 1;
LANK = find(strcmp([Markers.Labels],'LANK'));
pom_l(LANK) = 1;
LHEE = find(strcmp([Markers.Labels],'LHEE'));
pom_l(LHEE) = 1;
LTOE = find(strcmp([Markers.Labels],'LTOE'));
pom_l(LTOE) = 1;
LHipAngles = find(strcmp([Markers.Labels],'LHipAngles'));
pom_l(LHipAngles) = 1;
LKneeAngles = find(strcmp([Markers.Labels],'LKneeAngles'));
pom_l(LKneeAngles) = 1;
LAnkleAngles = find(strcmp([Markers.Labels],'LAnkleAngles'));
pom_l(LAnkleAngles) = 1;
LAbsAnkleAngle = find(strcmp([Markers.Labels],'LAbsAnkleAngle'));
pom_l(LAbsAnkleAngle) = 1;
LPelvisAngles = find(strcmp([Markers.Labels],'LPelvisAngles'));
pom_l(LPelvisAngles) = 1;
LFootProgressAngles = find(strcmp([Markers.Labels],'LFootProgressAngles'));
pom_l(LFootProgressAngles) = 1;
LAnklePower = find(strcmp([Markers.Labels],'LAnklePower'));
pom_l(LAnklePower) = 1;
LKneePower = find(strcmp([Markers.Labels],'LKneePower'));
pom_l(LKneePower) = 1;
LHipPower = find(strcmp([Markers.Labels],'LHipPower'));
pom_l(LHipPower) = 1;
LGroundReactionForce = find(strcmp([Markers.Labels],'LGroundReactionForce'));
pom_l(LGroundReactionForce) = 1;
LNormalisedGRF = find(strcmp([Markers.Labels],'LNormalisedGRF'));
pom_l(LNormalisedGRF) = 1;
LAnkleForce = find(strcmp([Markers.Labels],'LAnkleForce'));
pom_l(LAnkleForce) = 1;
LKneeForce = find(strcmp([Markers.Labels],'LKneeForce'));
pom_l(LKneeForce) = 1;
LHipForce = find(strcmp([Markers.Labels],'LHipForce'));
pom_l(LHipForce) = 1;
LGroundReactionMoment = find(strcmp([Markers.Labels],'LGroundReactionMoment'));
pom_l(LGroundReactionMoment) = 1;
LAnkleMoment = find(strcmp([Markers.Labels],'LAnkleMoment'));
pom_l(LAnkleMoment) = 1;
LKneeMoment = find(strcmp([Markers.Labels],'LKneeMoment'));
pom_l(LKneeMoment) = 1;
LHipMoment = find(strcmp([Markers.Labels],'LHipMoment'));
pom_l(LHipMoment) = 1;

% find and save the indexes of the variables describing the gait cycle in the variable
% 'indexes_left_side'
indexes_left_side = [LFEO LFEA LFEL LFEP LFOO LFOA LFOL LFOP LTIO LTIA LTIL LTIP LTOO LTOA LTOL LTOP PELO PELA PELL PELP LASI LPSI LTHI LKNE LTIB LANK LHEE LTOE LHipAngles LKneeAngles LAnkleAngles LAbsAnkleAngle LPelvisAngles LFootProgressAngles LAnklePower LKneePower LHipPower LGroundReactionForce LNormalisedGRF LAnkleForce LKneeForce LHipForce LGroundReactionMoment LAnkleMoment LKneeMoment LHipMoment].*3;

% create the variable 'pom2_l' to where the indexes of the variable describing the gait
% cycle in the all three planes are stored
pom2_l = zeros(1,length(indexes_left_side)*3);

for u = 1:length(indexes_left_side);
    
    pom2_l(u*3) = indexes_left_side(u);
    
end

for t = 1:length(pom2_l);
    
   if pom2_l(t) ~= 0;
      pom2_l(t-1) = pom2_l(t)-1;
      pom2_l(t-2) = pom2_l(t)-2;
      
   else
       
   end
   
end

% create the variable 'left_variables' to where the names of the variables describing
% the gait cycle are saved (it serves as a head of the output .csv file) and define
% the beggining and the end of the gait cycle and save it into the variables
% 'dif_b_left' and 'dif_e_left')
if length(pom2_l) == length(indexes_left_side)*3;

   left_variables = {'LFEO',	'LFEA',	'LFEL',	'LFEP',	'LFOO',	'LFOA',	'LFOL',	'LFOP',	'LTIO',	'LTIA',	'LTIL',	'LTIP',	'LTOO',	'LTOA',	'LTOL',	'LTOP',	'PELO',	'PELA',	'PELL',	'PELP',	'LASI',	'LPSI',	'LTHI',	'LKNE',	'LTIB',	'LANK',	'LHEE',	'LTOE',	'LHipAngles',	'LKneeAngles',	'LAnkleAngles',	'LAbsAnkleAngle',	'LPelvisAngles'	'LFootProgressAngles',	'LAnklePower',	'LKneePower',	'LHipPower',	'LGroundReactionForce',	'LNormalisedGRF',	'LAnkleForce',	'LKneeForce',	'LHipForce',	'LGroundReactionMoment',	'LAnkleMoment',	'LKneeMoment',	'LHipMoment'};
   first_frame = Markers.FirstFrame;
   last_frame = Markers.LastFrame;
   dif_b_left = fs_left_b-first_frame;
   dif_e_left = last_frame-fs_left_e;
   diference = fs_left_e-fs_left_b;

    % create the variable 'right_variables_xyz' to where the variables describing
    % the gait cycle into the three planes are saved within the gait cycle 
    if dif_b_left >= 0 && dif_e_left >= 0; 

       left_data = Markers.RawData(dif_b_left:(dif_b_left+diference),pom2_l);
       n = length(left_variables);
       left_variables_xyz = cell(1,3*n); 
       z = 1;
       
        while z < n ;
            
            for i = 1:3:3*n;
   
                left_variables_xyz(i)= strcat([left_variables(z)], '_x');
                left_variables_xyz(i+1)= strcat([left_variables(z)], '_y');
                left_variables_xyz(i+2) = strcat([left_variables(z)], '_z');
                z = z+1;
                
            end  
            
        end
        
       % create the variable 'left_data_double' to where the variables describing
       % the gait cycle are stored within the normalised gait cycle
       left_data_double_pom = double(left_data);
       len = size(left_data_double_pom);
       y1 = linspace(1,len(1,1),length_of_normalised_gait_cycle);
       
       for i = 1:len(1,2)

           left_data_double(:,i) = interp1(left_data_double_pom(:,i),y1);
           
       end

       % create the variable 'left_data_xyz' to where the variables describing
       % the gait cycle into the three planes and their names are stored
       left_data_cell = num2cell(left_data_double);
       left_data_xyz = cell(length_of_normalised_gait_cycle+1,length(left_data_double(1,:)));
       left_data_xyz(1,:) = left_variables_xyz;
       left_data_xyz(2:end,:) = left_data_cell;
       
    else
        
       left_data_xyz = {0};
       left_variables_xyz =0;
       left_data_double =0;
       dif_b_left = 0;
       dif_e_left = 0;
       
    end
    
else
    
    left_data_xyz = {0};
    left_variables_xyz =0;
    left_data_double =0;
    dif_b_left = 0;
    dif_e_left = 0;
    
end

end
