% Author: Veronika Svozilova
% Institution: The University Hospital Brno
% Personal e-mail adress: fauxpas.gkj@gmail.com

% function 'selection_of_gait_cycles_variables_right_limb' serves to select
% the variables describing the gait cycle in the three planes (the frontal, the sagittal,
% the transversal) for the right lower limb
function [right_data_xyz, right_variables_xyz, right_data_double, dif_b_right, dif_e_right] = selection_of_gait_cycles_variables_right_limb(Markers,fs_right_b, fs_right_e)

% define the length of the normalised gait cycle and the auxiliary variable 'pom_r'
% to which the variables of the structure 'Markers.mat' will be stored
length_of_normalised_gait_cycle = 101;
pom_r = zeros(1,length(Markers.Labels));

% define and find the location of the variables describing the gait cycles in the input structure 'Markers.mat', the location of these
% variables are stored into the variable 'pom_r'
RFEO = find(strcmp([Markers.Labels],'RFEO'));
pom_r(RFEO) = 1;
RFEA = find(strcmp([Markers.Labels],'RFEA'));
pom_r(RFEA) = 1;
RFEL = find(strcmp([Markers.Labels],'RFEL'));
pom_r(RFEL) = 1;
RFEP = find(strcmp([Markers.Labels],'RFEP'));
pom_r(RFEP) = 1;
RFOO = find(strcmp([Markers.Labels],'RFOO'));
pom_r(RFOO) = 1;
RFOA = find(strcmp([Markers.Labels],'RFOA'));
pom_r(RFOA) = 1;
RFOL = find(strcmp([Markers.Labels],'RFOL'));
pom_r(RFOL) = 1;
RFOP = find(strcmp([Markers.Labels],'RFOP'));
pom_r(RFOP) = 1;
RTIO = find(strcmp([Markers.Labels],'RTIO'));
pom_r(RTIO) = 1;
RTIA = find(strcmp([Markers.Labels],'RTIA'));
pom_r(RTIA) = 1;
RTIL = find(strcmp([Markers.Labels],'RTIL'));
pom_r(RTIL) = 1;
RTIP = find(strcmp([Markers.Labels],'RTIP'));
pom_r(RTIP) = 1;
RTOO = find(strcmp([Markers.Labels],'RTOO'));
pom_r(RTOO) = 1;
RTOA = find(strcmp([Markers.Labels],'RTOA'));
pom_r(RTOA) = 1;
RTOL = find(strcmp([Markers.Labels],'RTOL'));
pom_r(RTOL) = 1;
RTOP = find(strcmp([Markers.Labels],'RTOP'));
pom_r(RTOP) = 1;
PELO = find(strcmp([Markers.Labels],'PELO'));
pom_r(PELO) = 1;
PELA = find(strcmp([Markers.Labels],'PELA'));
pom_r(PELA) = 1;
PELL = find(strcmp([Markers.Labels],'PELL'));
pom_r(PELL) = 1;
PELP = find(strcmp([Markers.Labels],'PELP'));
pom_r(PELP) = 1;
RASI = find(strcmp([Markers.Labels],'RASI'));
pom_r(RASI) = 1;
RPSI = find(strcmp([Markers.Labels],'RPSI'));
pom_r(RPSI) = 1;
RTHI = find(strcmp([Markers.Labels],'RTHI'));
pom_r(RTHI) = 1;
RKNE = find(strcmp([Markers.Labels],'RKNE'));
pom_r(RKNE) = 1;
RTIB = find(strcmp([Markers.Labels],'RTIB'));
pom_r(RTIB) = 1;
RANK = find(strcmp([Markers.Labels],'RANK'));
pom_r(RANK) = 1;
RHEE = find(strcmp([Markers.Labels],'RHEE'));
pom_r(RHEE) = 1;
RTOE = find(strcmp([Markers.Labels],'RTOE'));
pom_r(RTOE) = 1;
RHipAngles = find(strcmp([Markers.Labels],'RHipAngles'));
pom_r(RHipAngles) = 1;
RKneeAngles = find(strcmp([Markers.Labels],'RKneeAngles'));
pom_r(RKneeAngles) = 1;
RAnkleAngles = find(strcmp([Markers.Labels],'RAnkleAngles'));
pom_r(RAnkleAngles) = 1;
RAbsAnkleAngle = find(strcmp([Markers.Labels],'RAbsAnkleAngle'));
pom_r(RAbsAnkleAngle) = 1;
RPelvisAngles = find(strcmp([Markers.Labels],'RPelvisAngles'));
pom_r(RPelvisAngles) = 1;
RFootProgressAngles = find(strcmp([Markers.Labels],'RFootProgressAngles'));
pom_r(RFootProgressAngles) = 1;
RAnklePower = find(strcmp([Markers.Labels],'RAnklePower'));
pom_r(RAnklePower) = 1;
RKneePower = find(strcmp([Markers.Labels],'RKneePower'));
pom_r(RKneePower) = 1;
RHipPower = find(strcmp([Markers.Labels],'RHipPower'));
pom_r(RHipPower) = 1;
RGroundReactionForce = find(strcmp([Markers.Labels],'RGroundReactionForce'));
pom_r(RGroundReactionForce) = 1;
RNormalisedGRF = find(strcmp([Markers.Labels],'RNormalisedGRF'));
pom_r(RNormalisedGRF) = 1;
RAnkleForce = find(strcmp([Markers.Labels],'RAnkleForce'));
pom_r(RAnkleForce) = 1;
RKneeForce = find(strcmp([Markers.Labels],'RKneeForce'));
pom_r(RKneeForce) = 1;
RHipForce = find(strcmp([Markers.Labels],'RHipForce'));
pom_r(RHipForce) = 1;
RGroundReactionMoment = find(strcmp([Markers.Labels],'RGroundReactionMoment'));
pom_r(RGroundReactionMoment) = 1;
RAnkleMoment = find(strcmp([Markers.Labels],'RAnkleMoment'));
pom_r(RAnkleMoment) = 1;
RKneeMoment = find(strcmp([Markers.Labels],'RKneeMoment'));
pom_r(RKneeMoment) = 1;
RHipMoment = find(strcmp([Markers.Labels],'RHipMoment'));
pom_r(RHipMoment) = 1;

% find and save the indexes of the variables describing the gait cycle in the variable
% 'indexes_right_side'
indexes_right_side = [RFEO RFEA RFEL RFEP RFOO RFOA RFOL RFOP RTIO RTIA RTIL RTIP RTOO RTOA RTOL RTOP PELO PELA PELL PELP RASI RPSI RTHI RKNE RTIB RANK RHEE RTOE RHipAngles RKneeAngles RAnkleAngles RAbsAnkleAngle RPelvisAngles RFootProgressAngles RAnklePower RKneePower RHipPower RGroundReactionForce RNormalisedGRF RAnkleForce RKneeForce RHipForce RGroundReactionMoment RAnkleMoment RKneeMoment RHipMoment].*3;

% create the variable 'pom2_r' to where the indexes of the variable describing the gait
% cycle in the all three planes are stored
pom2_r = zeros(1,length(indexes_right_side)*3);

for uu = 1:length(indexes_right_side);
    
    pom2_r(uu*3) = indexes_right_side(uu);
    
end

for tt = 1:length(pom2_r);
    
   if pom2_r(tt) ~= 0;
      pom2_r(tt-1) = pom2_r(tt)-1;
      pom2_r(tt-2) = pom2_r(tt)-2;
      
   else
       
   end
   
end

% create the variable 'right_variables' to where the names of the variables describing
% the gait cycle are saved (it serves as a head of output .csv file) and define
% the beggining and the end of the gait cycle and save it into the variables
% 'dif_b_right' and 'dif_e_right')
if length(pom2_r) == length(indexes_right_side)*3;

   right_variables = {'RFEO',	'RFEA',	'RFEL',	'RFEP',	'RFOO',	'RFOA',	'RFOL',	'RFOP',	'RTIO',	'RTIA',	'RTIL',	'RTIP',	'RTOO',	'RTOA',	'RTOL',	'RTOP',	'PELO',	'PELA',	'PELL',	'PELP',	'RASI',	'RPSI',	'RTHI',	'RKNE',	'RTIB',	'RANK',	'RHEE',	'RTOE',	'RHipAngles',	'RKneeAngles',	'RAnkleAngles',	'RAbsAnkleAngle',	'RPelvisAngles'	'RFootProgressAngles',	'RAnklePower',	'RKneePower',	'RHipPower',	'RGroundReactionForce',	'RNormalisedGRF',	'RAnkleForce',	'RKneeForce',	'RHipForce',	'RGroundReactionMoment',	'RAnkleMoment',	'RKneeMoment',	'RHipMoment'};
   first_frame = Markers.FirstFrame;
   last_frame = Markers.LastFrame;
   dif_b_right = fs_right_b-first_frame;
   dif_e_right = last_frame-fs_right_e;
   diference = fs_right_e-fs_right_b;

    % create the variable 'right_variables_xyz' to where the variables describing
    % the gait cycle into the three planes are saved within the gait cycle 
    if dif_b_right >= 0 && dif_e_right >= 0; 
       
       right_data = Markers.RawData(dif_b_right:(dif_b_right+diference),pom2_r);
       nn = length(right_variables);
       right_variables_xyz = cell(1,3*nn); 
       zz = 1;
       
        while zz < nn ;
            
            for ii = 1:3:3*nn;
   
                right_variables_xyz(ii)= strcat([right_variables(zz)], '_x');
                right_variables_xyz(ii+1)= strcat([right_variables(zz)], '_y');
                right_variables_xyz(ii+2) = strcat([right_variables(zz)], '_z');
                zz = zz+1;
            
            end   
        end
        
       % create the variable 'right_data_double' to where the variables describing
       % the gait cycle are stored within the normalised gait cycle
       right_data_double_pom = double(right_data);
       len = size(right_data_double_pom);
       y11 = linspace(1,len(1,1),length_of_normalised_gait_cycle);
       
       for i = 1:len(1,2)

           right_data_double(:,i) = interp1(right_data_double_pom(:,i),y11);
           
       end

       % create the variable 'right_data_xyz' to where the variables describing
       % the gait cycle into the three planes and their names are stored  
       right_data_cell = num2cell(right_data_double);
       right_data_xyz = cell(length_of_normalised_gait_cycle+1,length(right_data_double(1,:)));
       right_data_xyz(1,:) = right_variables_xyz;
       right_data_xyz(2:end,:) = right_data_cell;
       
    else
        
       right_data_xyz = {0};
       right_variables_xyz =0;
       right_data_double =0;
       dif_b_right = 0;
       dif_e_right = 0;
    
    end
    
else
    
    right_data_xyz = {0};
    right_variables_xyz =0;
    right_data_double =0;
    dif_b_right = 0;
    dif_e_right = 0;
    
end

end
