% Author: Veronika Svozilova
% Institution: The University Hospital Brno
% Personal e-mail adress: fauxpas.gkj@gmail.com

% function 'normalised_gait_cycles' serves to preprocess the gait
% cycle's data, the input: Events.mat, Markers.mat, the output: the normalised gait
% cycles saved to .csv files
function [right_data_xyz, left_data_xyz] = normalised_gait_cycles(path_input_data, path_output_data);

% add the path of the built-in functions
path_functions = addpath('.\Libs');

% use 'recurse_subfolders_R2016b' to create the list of the input data (the input
% data of the examinated pacients which contain the structure 'Events.mat' and
% 'Markers.mat')
recurse_subfolders_R2016b;

    % for cycle serves to preprocess the input data of the all examined patients
    for i = 1:length(listOfFolderNames);
    
        %% Determination of the gait cycle's borders
        % load the structure 'Events.mat' from the input dataset
        load(strcat(listOfFolderNames{1, i},'\Events.mat'));

        % use function 'bounding_of_gait_cycles' to determine the beginning and the
        % end of the gait cycles for both limbs
        [fs_right_b, fs_right_e, fs_left_b, fs_left_e] = bounding_of_gait_cycles(Events);
            
        %% Determination of the gait cycle's variables
        % load the structure 'Markers.mat' from the input dataset
        load(strcat(listOfFolderNames{1, i},'\Markers.mat'));
           
           % the case when the gait cycles of both lower limbs were
           % acquired simulthaneously
           if fs_right_b > 0 && fs_right_e > 0 && fs_left_b > 0 && fs_left_e > 0;
               
           % use two funtions 'selection_of_gait_cycles_variables_right_limb' and
           % 'selection_of_gait_cycles_variables_left_limb' to determine
           % the gait cycle's variables which describe the gait cycle in the frontal, the sagittal and the tranversal
           % plane
           [right_data_xyz, right_variables_xyz, right_data_double, dif_b_right, dif_e_right] = selection_of_gait_cycles_variables_right_limb(Markers,fs_right_b, fs_right_e);
           [left_data_xyz, left_variables_xyz, left_data_double, dif_b_left, dif_e_left] = selection_of_gait_cycles_variables_left_limb(Markers,fs_left_b, fs_left_e);
        
           % the case when the gait cycle of the right lower limb was
           % acquired separately
           elseif fs_right_b > 0 && fs_right_e > 0;
           
           % use function 'selection_of_gait_cycles_variables_right_limb'
           % to determine the gait cycle's variables of the right lower
           % limb in the frontal, the sagittal and the transversal plane
           [right_data_xyz, right_variables_xyz, right_data_double, dif_b_right, dif_e_right] = selection_of_gait_cycles_variables_right_limb(Markers,fs_right_b, fs_right_e);
           left_data_xyz = cell(1,1);
           left_data_xyz{1, 1} = 0;
           
           elseif fs_left_b > 0 && fs_left_e > 0;
               
           % use function 'selection_of_gait_cycles_variables_left_limb'
           % to determine the gait cycle's variables of the left lower
           % limb in the frontal, the sagittal and the transversal plane
           [left_data_xyz, left_variables_xyz, left_data_double, dif_b_left, dif_e_left] = selection_of_gait_cycles_variables_left_limb(Markers,fs_left_b, fs_left_e);
           right_data_xyz = cell(1,1);
           right_data_xyz{1, 1} = 0;
           
           else
           
           end
        
        %% Storage of the output normalised gait cycle's data
        % use MATLAB function 'fileparts' to get parts of the file name 
        [filepath,name,ext] = fileparts(listOfFolderNames{1, i});
        
        % the case when the gait cycles were acquired for both lower limbs simulthaneously 
        if right_data_xyz{1, 1}  > 0 & left_data_xyz{1, 1}  > 0;

        % use function 'title_of_normalised_gait_cycles' to name the final output data by our specific format
        [name_final_left, name_final_right, T, T2] = title_of_normalised_gait_cycles(name, right_data_xyz, left_data_xyz);

        % get to the path of the output data and save the final preprocessed normalised
        % gait cycles as .csv files (.csv files are named in format: "<LastName>-<FirstName>-<YearOfBirthInFormat:YY>-<DateOfExaminationInFormat:DDMMYYYY>-Cal-<GaitCycleNumber>-<LimbType:L|R>")
        cd(path_output_data);
        writetable(T,[name_final_right,'.csv']);
        writetable(T2,[name_final_left,'.csv']);
        
        % the case when the gait cycle for the right lower limb was
        % acquired separately
        elseif right_data_xyz{1, 1}  > 0 & left_data_xyz{1, 1}  == 0;
        
        % use function 'title_of_normalised_gait_cycles' to name the final output data by our specific format
        [name_final_left, name_final_right, T, T2] = title_of_normalised_gait_cycles(name, right_data_xyz, left_data_xyz);

        % get to the path of the output data and save the final preprocessed normalised
        % gait cycles as .csv files (.csv files are named in format: "<LastName>-<FirstName>-<YearOfBirthInFormat:YY>-<DateOfExaminationInFormat:DDMMYYYY>-Cal-<GaitCycleNumber>-<LimbType:L|R>")
        cd(path_output_data);
        writetable(T,[name_final_right,'.csv']);
        
        % the case when the gait cycle for the left lower limb was
        % acquired separately
        elseif left_data_xyz{1, 1}  > 0 & right_data_xyz{1, 1}  == 0;
        
        % use function 'title_of_normalised_gait_cycles' to name the final output data by our specific format
        [name_final_left, name_final_right, T, T2] = title_of_normalised_gait_cycles(name, right_data_xyz, left_data_xyz);

        % get to the path of the output data and save the final preprocessed normalised
        % gait cycles as .csv files (.csv files are named in format: "<LastName>-<FirstName>-<YearOfBirthInFormat:YY>-<DateOfExaminationInFormat:DDMMYYYY>-Cal-<GaitCycleNumber>-<LimbType:L|R>")
        cd(path_output_data);
        writetable(T2,[name_final_left,'.csv']);
        
        else
               
        end
       
    Markers = 0;
    
    end
    
end




